/**
 * Copyright (c) 2010 Generative Software Development Lab, University of Waterloo, Canada. All Rights Reserved
 *
 * This library is free software; you can redistribute it and/or modify it under the terms of the 
 * GNU Lesser General Public License as published by the Free Software Foundation; either version 
 * 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; 
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See 
 * the GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License along with this library;
 * if not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, 
 * MA  02110-1301  USA
 * 
 * You can find the license also here: http://www.gnu.org/copyleft/lesser.html 
 */
package ca.uwaterloo.gsd.icsm2010.clients.swing;

import ca.uwaterloo.gsd.icsm2010.wrappers.swing2swt.awt.Component;
import ca.uwaterloo.gsd.icsm2010.wrappers.swing2swt.awt.Container;
import ca.uwaterloo.gsd.icsm2010.wrappers.swing2swt.awt.Dimension;
import ca.uwaterloo.gsd.icsm2010.wrappers.swing2swt.awt.FlowLayout;
import ca.uwaterloo.gsd.icsm2010.wrappers.swing2swt.awt.event.ActionEvent;
import ca.uwaterloo.gsd.icsm2010.wrappers.swing2swt.awt.event.ActionListener;

import ca.uwaterloo.gsd.icsm2010.wrappers.swing2swt.swing.DefaultListModel;
import ca.uwaterloo.gsd.icsm2010.wrappers.swing2swt.swing.JButton;
import ca.uwaterloo.gsd.icsm2010.wrappers.swing2swt.swing.JCheckBox;
import ca.uwaterloo.gsd.icsm2010.wrappers.swing2swt.swing.JFrame;
import ca.uwaterloo.gsd.icsm2010.wrappers.swing2swt.swing.JList;
import ca.uwaterloo.gsd.icsm2010.wrappers.swing2swt.swing.JScrollPane;

/* Using the wrapper types
import ca.uwaterloo.gsd.icsm2010.wrappers.swing2swt.awt.Component;
import ca.uwaterloo.gsd.icsm2010.wrappers.swing2swt.awt.Container;
import ca.uwaterloo.gsd.icsm2010.wrappers.swing2swt.awt.Dimension;
import ca.uwaterloo.gsd.icsm2010.wrappers.swing2swt.awt.FlowLayout;
import ca.uwaterloo.gsd.icsm2010.wrappers.swing2swt.awt.event.ActionEvent;
import ca.uwaterloo.gsd.icsm2010.wrappers.swing2swt.awt.event.ActionListener;

import ca.uwaterloo.gsd.icsm2010.wrappers.swing2swt.swing.DefaultListModel;
import ca.uwaterloo.gsd.icsm2010.wrappers.swing2swt.swing.JButton;
import ca.uwaterloo.gsd.icsm2010.wrappers.swing2swt.swing.JCheckBox;
import ca.uwaterloo.gsd.icsm2010.wrappers.swing2swt.swing.JFrame;
import ca.uwaterloo.gsd.icsm2010.wrappers.swing2swt.swing.JList;
import ca.uwaterloo.gsd.icsm2010.wrappers.swing2swt.swing.JScrollPane;
*/

/* Using the original Swing types
import java.awt.Component;
import java.awt.Container;
import java.awt.Dimension;
import java.awt.FlowLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.DefaultListModel;
import javax.swing.JButton;
import javax.swing.JCheckBox;
import javax.swing.JFrame;
import javax.swing.JList;
import javax.swing.JScrollPane;
*/

/**
 * This is a simple GUI application using Swing.
 * 
 * This version uses the Swing2SWT API - you should see SWT widgets.
 * 
 * @author Thiago Tonelli Bartolomei
 */
public class Swing2SWTClient {

	public static void main(String[] args) {

		final JFrame frame = new JFrame();
		Container pane = frame.getContentPane();
		
		JScrollPane scroll = new JScrollPane();
		scroll.setPreferredSize(new Dimension(100, 70));
		DefaultListModel model = new DefaultListModel();
		model.addElement("red");
		model.addElement("yellow");
		model.addElement("green");
		model.addElement("blue");
		JList list = new JList(model);
		
		final JCheckBox check = new JCheckBox("Translate All");
		
		
		JButton translate = new JButton("Translate");
		
		translate.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				new Translator().translateLists(frame, check.isSelected());
			}
		});
		
		pane.setLayout(new FlowLayout());
		
		scroll.getViewport().setView(list);
		pane.add(scroll);
		pane.add(check);
		pane.add(translate);
		
		frame.pack();
		frame.setVisible(true);
		frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
	}
	
	public static class Translator {
		
		public void translateLists(Container container, boolean all) {
			for (Component c : container.getComponents()) {
				if (c instanceof JList) {
					JList list = (JList) c;
					DefaultListModel model = (DefaultListModel) list.getModel();
					int size = model.getSize();
					for(int i = 0; i < size; i++) {
						if (all || list.isSelectedIndex(i)) {
							model.add(i, translate((String) model.remove(i)));
						}
					}
					
				} else if (c instanceof Container) {
					translateLists((Container) c, all);
				}
			}
		}
		
		/**
		 * Translates the String.
		 * 
		 * @param s
		 * @return
		 */
		public String translate(String s) {
			if ("red".equals(s)) return "rot";
			if ("rot".equals(s)) return "red";
			
			if ("yellow".equals(s)) return "gelb";
			if ("gelb".equals(s)) return "yellow";
			
			if ("green".equals(s)) return "gruen";
			if ("gruen".equals(s)) return "green";
			
			if ("blue".equals(s)) return "blau";
			if ("blau".equals(s)) return "blue";
			return s;
		}
	}
}
