/**
 * Copyright (c) 2010 Generative Software Development Lab, University of Waterloo, Canada. All Rights Reserved
 *
 * This library is free software; you can redistribute it and/or modify it under the terms of the 
 * GNU Lesser General Public License as published by the Free Software Foundation; either version 
 * 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; 
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See 
 * the GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License along with this library;
 * if not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, 
 * MA  02110-1301  USA
 * 
 * You can find the license also here: http://www.gnu.org/copyleft/lesser.html 
 */
package ca.uwaterloo.gsd.icsm2010.clients.swt;

import ca.uwaterloo.gsd.icsm2010.wrappers.swt2swing.SWT;
import ca.uwaterloo.gsd.icsm2010.wrappers.swt2swing.events.SelectionAdapter;
import ca.uwaterloo.gsd.icsm2010.wrappers.swt2swing.events.SelectionEvent;
import ca.uwaterloo.gsd.icsm2010.wrappers.swt2swing.layout.RowData;
import ca.uwaterloo.gsd.icsm2010.wrappers.swt2swing.layout.RowLayout;
import ca.uwaterloo.gsd.icsm2010.wrappers.swt2swing.widgets.Button;
import ca.uwaterloo.gsd.icsm2010.wrappers.swt2swing.widgets.Composite;
import ca.uwaterloo.gsd.icsm2010.wrappers.swt2swing.widgets.Control;
import ca.uwaterloo.gsd.icsm2010.wrappers.swt2swing.widgets.Display;
import ca.uwaterloo.gsd.icsm2010.wrappers.swt2swing.widgets.List;
import ca.uwaterloo.gsd.icsm2010.wrappers.swt2swing.widgets.Shell;

/* Using the wrapper types
import ca.uwaterloo.gsd.icsm2010.wrappers.swt2swing.SWT;
import ca.uwaterloo.gsd.icsm2010.wrappers.swt2swing.events.SelectionAdapter;
import ca.uwaterloo.gsd.icsm2010.wrappers.swt2swing.events.SelectionEvent;
import ca.uwaterloo.gsd.icsm2010.wrappers.swt2swing.layout.RowData;
import ca.uwaterloo.gsd.icsm2010.wrappers.swt2swing.layout.RowLayout;
import ca.uwaterloo.gsd.icsm2010.wrappers.swt2swing.widgets.Button;
import ca.uwaterloo.gsd.icsm2010.wrappers.swt2swing.widgets.Composite;
import ca.uwaterloo.gsd.icsm2010.wrappers.swt2swing.widgets.Control;
import ca.uwaterloo.gsd.icsm2010.wrappers.swt2swing.widgets.Display;
import ca.uwaterloo.gsd.icsm2010.wrappers.swt2swing.widgets.List;
import ca.uwaterloo.gsd.icsm2010.wrappers.swt2swing.widgets.Shell;
*/

/* Using the original SWT types
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.layout.RowData;
import org.eclipse.swt.layout.RowLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.Display;
import org.eclipse.swt.widgets.List;
import org.eclipse.swt.widgets.Shell;
*/


/**
 * This is a simple GUI application using SWT.
 * 
 * This version uses the SWT2Swing API - you should see Swing widgets.
 * 
 * @author Thiago Tonelli Bartolomei
 */
public class SWT2SwingClient {

	public static void main(String[] args) {
		
		Display display = new Display();
		final Shell shell = new Shell(display);

		List list = new List(shell, 
				SWT.BORDER | SWT.MULTI | SWT.V_SCROLL);
		list.setLayoutData(new RowData(100, 70));
		list.add("red");
		list.add("yellow");
		list.add("green");
		list.add("blue");
		
		
		final Button check = new Button(shell, SWT.CHECK);
		check.setText("Translate All");
		
		Button translate = new Button(shell, SWT.PUSH);
		translate.setText("Translate");
		translate.addSelectionListener(new SelectionAdapter() {
			public void widgetSelected(SelectionEvent e) {
				new Translator().translateLists(shell, check.getSelection());
			}
		});
		
		RowLayout layout = new RowLayout();
		layout.center = true;
		shell.setLayout(layout);
		
		shell.pack();
		shell.open();
		while (!shell.isDisposed ()) {
			if (!display.readAndDispatch()) display.sleep();
		}
		display.dispose();
	}
	
	public static class Translator {
		
		public void translateLists(Composite composite, boolean all) {
			for (Control c : composite.getChildren()) {
				if (c instanceof List) {
					List list = (List) c;
					int size = list.getItemCount();
					for(int i = 0; i < size; i++) {
						if (all || list.isSelected(i)) {
							String item = list.getItem(i);
							list.remove(i);
							list.add(translate(item), i);
						}
					}
					
				} else if (c instanceof Composite) {
					translateLists((Composite) c, all);
				}
			}
		}
		
		
		/**
		 * Translates the String.
		 * 
		 * @param s
		 * @return
		 */
		public String translate(String s) {
			if ("red".equals(s)) return "rot";
			if ("rot".equals(s)) return "red";
			
			if ("yellow".equals(s)) return "gelb";
			if ("gelb".equals(s)) return "yellow";
			
			if ("green".equals(s)) return "gruen";
			if ("gruen".equals(s)) return "green";
			
			if ("blue".equals(s)) return "blau";
			if ("blau".equals(s)) return "blue";
			return s;
		}
	}
}
