/**
 * Copyright (c) 2010 Generative Software Development Lab, University of Waterloo, Canada. All Rights Reserved
 *
 * This library is free software; you can redistribute it and/or modify it under the terms of the 
 * GNU Lesser General Public License as published by the Free Software Foundation; either version 
 * 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; 
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See 
 * the GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License along with this library;
 * if not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, 
 * MA  02110-1301  USA
 * 
 * You can find the license also here: http://www.gnu.org/copyleft/lesser.html 
 */
package ca.uwaterloo.gsd.icsm2010.wrappers.swing2swt.awt;

import java.util.Map;
import java.util.WeakHashMap;

import org.eclipse.swt.graphics.Point;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.Display;
import org.eclipse.swt.widgets.Widget;

import ca.uwaterloo.gsd.icsm2010.patterns.FactoryMethod;
import ca.uwaterloo.gsd.icsm2010.patterns.ObjectAdapter;
import ca.uwaterloo.gsd.icsm2010.patterns.WrappingIdentityMap;

/**
 * This sits on top of the widget inheritance hierarchy.
 * 
 * This surrogate implements a lot of infrastructure for all types, such as
 * factory methods, the main object adapter field and wrapping identity map.
 * 
 * @author Thiago Tonelli Bartolomei
 */
public abstract class Component {

	@ObjectAdapter
	protected Widget adaptee = null;
	
	// Made public to be accessed outside package/hierarchy
	public Widget getAdaptee() {
		return adaptee;
	}
	
	protected void setAdaptee(Widget w) {
		this.adaptee = w;
		this.registerAdaptee(w);
	}
	
	// Singleton Pattern
	private static Display display = null;
	
	Display getDisplay() {
		if (null == display) {
			display = new Display();
		}
		return display;
	}
	
	@FactoryMethod
	protected abstract void createAdaptee(Composite parent);
	
	@WrappingIdentityMap
	private static Map<Widget, Component> map = new WeakHashMap<Widget, Component>();
	
	@WrappingIdentityMap
	void registerAdaptee(Widget adaptee) {
		map.put(adaptee, this);
	}
	
	@WrappingIdentityMap
	Component getSurrogate(Widget adaptee, Class<?> surrogateClass) {
		if (! map.containsKey(adaptee)) {
			map.put(adaptee, createSurrogate(adaptee, surrogateClass));
		}
		return map.get(adaptee);
	}
	
	@WrappingIdentityMap
	Component createSurrogate(Widget adaptee, Class<?> surrogateClass) {
		// TODO not needed in this example.
		return null;
	}
	
	// Protected API
	protected Component() {
	}
	
	// Public API
	public Dimension getPreferredSize() {
		// Inheritance mismatch
		if (getAdaptee() instanceof Control) {
			Point p = ((Control) getAdaptee()).computeSize(-1, -1);
			return new Dimension(p.x, p.y);
		}
		return new Dimension(0, 0);
	}
}
