/**
 * Copyright (c) 2010 Generative Software Development Lab, University of Waterloo, Canada. All Rights Reserved
 *
 * This library is free software; you can redistribute it and/or modify it under the terms of the 
 * GNU Lesser General Public License as published by the Free Software Foundation; either version 
 * 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; 
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See 
 * the GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License along with this library;
 * if not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, 
 * MA  02110-1301  USA
 * 
 * You can find the license also here: http://www.gnu.org/copyleft/lesser.html 
 */
package ca.uwaterloo.gsd.icsm2010.wrappers.swing2swt.awt;

import org.eclipse.swt.SWT;
import org.eclipse.swt.widgets.Display;
import org.eclipse.swt.widgets.Shell;

import ca.uwaterloo.gsd.icsm2010.patterns.FactoryMethod;

/**
 * Wraps a Shell, which represents windows in SWT.
 * 
 * @author Thiago Tonelli Bartolomei
 */
public class Window extends Container {

	// Wrapper Refinement
	public Shell getAdaptee() {
		return (Shell) adaptee;
	}
	
	@FactoryMethod
	void createAdaptee(int style) {
		this.setAdaptee(new Shell(getDisplay(), style));
	}
	
	// Protected API
	protected Window() {
		createAdaptee(SWT.SHELL_TRIM);
	}
	
	// Public API
	public void pack() {
		getAdaptee().pack();
	}
	
	public void setVisible(boolean b) {
		if(b) {
			Shell shell = getAdaptee();
			Display display = getDisplay();
			
			shell.open();
			while (!shell.isDisposed ()) {
				if (!display.readAndDispatch()) display.sleep();
			}
			display.dispose();
			
		} else {
			getAdaptee().setVisible(false);
		}
	}
}
