/**
 * Copyright (c) 2010 Generative Software Development Lab, University of Waterloo, Canada. All Rights Reserved
 *
 * This library is free software; you can redistribute it and/or modify it under the terms of the 
 * GNU Lesser General Public License as published by the Free Software Foundation; either version 
 * 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; 
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See 
 * the GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License along with this library;
 * if not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, 
 * MA  02110-1301  USA
 * 
 * You can find the license also here: http://www.gnu.org/copyleft/lesser.html 
 */
package ca.uwaterloo.gsd.icsm2010.wrappers.swing2swt.swing;

import java.util.ArrayList;
import java.util.List;

import org.eclipse.swt.SWT;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;

import ca.uwaterloo.gsd.icsm2010.patterns.DelayedInstantiation;
import ca.uwaterloo.gsd.icsm2010.patterns.FactoryMethod;
import ca.uwaterloo.gsd.icsm2010.patterns.InverseDelegation;
import ca.uwaterloo.gsd.icsm2010.wrappers.swing2swt.awt.event.ActionListener;
import ca.uwaterloo.gsd.icsm2010.wrappers.swing2swt.swing.internal.InverseActionListener;

/**
 * Wraps an SWT Button.
 * 
 * @author Thiago Tonelli Bartolomei
 */
public class JButton extends AbstractButton {

	@DelayedInstantiation
	protected String text = null;
	
	@DelayedInstantiation
	protected List<ActionListener> listeners = new ArrayList<ActionListener>();
	
	public Button getAdaptee() {
		return (Button) adaptee;
	}
	
	@FactoryMethod
	@DelayedInstantiation
	@InverseDelegation
	protected void createAdaptee(Composite parent) {
		
		Button button = new Button(parent, SWT.PUSH);
		this.setAdaptee(button);
		
		// Delayed Instantiation
		button.setText(text);
		
		for(ActionListener l : listeners) {
			button.addSelectionListener(new InverseActionListener(l));
		}
	}
	
	// Public API
	public JButton(String text) {
		if (null == getAdaptee())
			this.text = text;
		else
			getAdaptee().setText(text);
	}
	
	@InverseDelegation
	public void addActionListener(ActionListener l) {
		if (null == getAdaptee())
			this.listeners.add(l);
		else
			getAdaptee().addSelectionListener(new InverseActionListener(l));
	}
}
