/**
 * Copyright (c) 2010 Generative Software Development Lab, University of Waterloo, Canada. All Rights Reserved
 *
 * This library is free software; you can redistribute it and/or modify it under the terms of the 
 * GNU Lesser General Public License as published by the Free Software Foundation; either version 
 * 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; 
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See 
 * the GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License along with this library;
 * if not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, 
 * MA  02110-1301  USA
 * 
 * You can find the license also here: http://www.gnu.org/copyleft/lesser.html 
 */
package ca.uwaterloo.gsd.icsm2010.wrappers.swing2swt.swing;

import org.eclipse.swt.SWT;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.List;

import ca.uwaterloo.gsd.icsm2010.patterns.FactoryMethod;

/**
 * Wraps, together with a ListModel, an SWT List.
 * 
 * @author Thiago Tonelli Bartolomei
 */
public class JList extends JComponent {

	// Surrogate reference for Many to One
	protected ListModel dataModel = null;
	
	public List getAdaptee() {
		return (List) adaptee;
	}
	
	@FactoryMethod
	protected void createAdaptee(Composite parent) {
		
		List list = new List(parent, SWT.BORDER | SWT.MULTI);
		this.setAdaptee(list);
		
		for(int i = 0; i < dataModel.getSize(); i++) {
			list.add(dataModel.getElementAt(i).toString());
		}
		
		// To be more general we would have to add a method to the ListModel interface.
		((DefaultListModel) dataModel).setJList(this);
	}
	
	// Public API
	public JList(ListModel dataModel) {
		this.dataModel = dataModel;
	}
	
	public ListModel getModel() {
		return this.dataModel;
	}
	
	public boolean isSelectedIndex(int index) {
		return getAdaptee().isSelected(index);
	}
}
