/**
 * Copyright (c) 2010 Generative Software Development Lab, University of Waterloo, Canada. All Rights Reserved
 *
 * This library is free software; you can redistribute it and/or modify it under the terms of the 
 * GNU Lesser General Public License as published by the Free Software Foundation; either version 
 * 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; 
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See 
 * the GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License along with this library;
 * if not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, 
 * MA  02110-1301  USA
 * 
 * You can find the license also here: http://www.gnu.org/copyleft/lesser.html 
 */
package ca.uwaterloo.gsd.icsm2010.wrappers.swing2swt.swing;


import org.eclipse.swt.SWT;
import org.eclipse.swt.custom.ScrolledComposite;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;

import ca.uwaterloo.gsd.icsm2010.patterns.DelayedInstantiation;
import ca.uwaterloo.gsd.icsm2010.patterns.FactoryMethod;
import ca.uwaterloo.gsd.icsm2010.wrappers.swing2swt.awt.Component;

/**
 * Wraps, together with a Component, an SWT's ScrolledComposite.
 * 
 * Because JViewport also implements a Composite role (i.e., it can have sub-widgets),
 * we also implement the delayed instantiation pending infrastructure here. But since
 * it is a sub-class of Container, we reuse some methods and the pending list from there.
 * 
 * @author Thiago Tonelli Bartolomei
 */
public class JViewport extends JComponent {

	Component view = null;
	
	public ScrolledComposite getAdaptee() {
		return (ScrolledComposite) adaptee;
	}
	
	@FactoryMethod
	protected void createAdaptee(Composite parent) {
		ScrolledComposite composite = new ScrolledComposite(parent, SWT.BORDER | SWT.H_SCROLL | SWT.V_SCROLL);
		this.setAdaptee(composite);
		
		this.createPending();
		
		Control control = (Control) view.getAdaptee();
		composite.setContent(control);
		composite.setMinSize(control.computeSize(SWT.DEFAULT, SWT.DEFAULT));
	}
	
	// Public API
	@DelayedInstantiation
	public void setView(Component view) {
		// this should behave just like Container.add()
		this.view = view;
		
		if (null == getAdaptee()) {
			this.addPending(view);
		} else {
			this.wire(view);
		}
	 }
}
