/**
 * Copyright (c) 2010 Generative Software Development Lab, University of Waterloo, Canada. All Rights Reserved
 *
 * This library is free software; you can redistribute it and/or modify it under the terms of the 
 * GNU Lesser General Public License as published by the Free Software Foundation; either version 
 * 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; 
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See 
 * the GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License along with this library;
 * if not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, 
 * MA  02110-1301  USA
 * 
 * You can find the license also here: http://www.gnu.org/copyleft/lesser.html
 */
package ca.uwaterloo.gsd.icsm2010.wrappers.swt2swing.events.internal;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import ca.uwaterloo.gsd.icsm2010.patterns.ClassAdapter;
import ca.uwaterloo.gsd.icsm2010.patterns.InverseDelegation;
import ca.uwaterloo.gsd.icsm2010.patterns.ObjectAdapter;
import ca.uwaterloo.gsd.icsm2010.patterns.WrappingIdentityMap;
import ca.uwaterloo.gsd.icsm2010.wrappers.swt2swing.events.SelectionEvent;
import ca.uwaterloo.gsd.icsm2010.wrappers.swt2swing.events.SelectionListener;

/**
 * Applies an inverse adapter pattern. Behaves as an action listener on the
 * target API and delegates events to its selection listener adaptee.
 * 
 * @author Thiago Tonelli Bartolomei
 */
@InverseDelegation
@ClassAdapter
public class InverseSelectionListener implements ActionListener {

	@ObjectAdapter
	SelectionListener adaptee = null;

	@WrappingIdentityMap
	public InverseSelectionListener(SelectionListener adaptee) {
		this.adaptee = adaptee;
	}

	// Public API
	public void actionPerformed(ActionEvent e) {
		adaptee.widgetSelected(new SelectionEvent(e));
	}
}
