/**
 * Copyright (c) 2010 Generative Software Development Lab, University of Waterloo, Canada. All Rights Reserved
 *
 * This library is free software; you can redistribute it and/or modify it under the terms of the 
 * GNU Lesser General Public License as published by the Free Software Foundation; either version 
 * 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; 
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See 
 * the GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License along with this library;
 * if not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, 
 * MA  02110-1301  USA
 * 
 * You can find the license also here: http://www.gnu.org/copyleft/lesser.html 
 */
package ca.uwaterloo.gsd.icsm2010.wrappers.swt2swing.widgets;

import javax.swing.AbstractButton;

import ca.uwaterloo.gsd.icsm2010.patterns.FactoryMethod;
import ca.uwaterloo.gsd.icsm2010.patterns.InverseDelegation;
import ca.uwaterloo.gsd.icsm2010.patterns.LayeredAdapter;
import ca.uwaterloo.gsd.icsm2010.wrappers.swt2swing.events.SelectionListener;
import ca.uwaterloo.gsd.icsm2010.wrappers.swt2swing.events.internal.InverseSelectionListener;
import ca.uwaterloo.gsd.icsm2010.wrappers.swt2swing.widgets.internal.IButton;
import ca.uwaterloo.gsd.icsm2010.wrappers.swt2swing.widgets.internal.IButton.IButtonFactory;

/**
 * A Button can represent either a JButton or a JCheckBox.
 * 
 * @author Thiago Tonelli Bartolomei
 */
public class Button extends Control {

	// Adaptee Refinement
	AbstractButton getAdaptee() {
		return (AbstractButton) adaptee;
	}
	
	@LayeredAdapter
	IButton getButton() {
		return (IButton) adaptee;
	}
	
	@FactoryMethod
	@LayeredAdapter
	void createAdaptee(int style) {
		this.setAdaptee((AbstractButton) IButtonFactory.createIButton(style));
	}
	
	// Public API
	public Button(Composite parent, int style) {
		super(parent, style);
	}
	
	public void setText(String text) {
		getButton().setText(text);
	}
	
	@InverseDelegation
	public void addSelectionListener(SelectionListener listener) {
		getButton().addActionListener(new InverseSelectionListener(listener));
	}
	
	public boolean getSelection() {
		return getButton().isSelected();
	}
}
