/**
 * Copyright (c) 2010 Generative Software Development Lab, University of Waterloo, Canada. All Rights Reserved
 *
 * This library is free software; you can redistribute it and/or modify it under the terms of the 
 * GNU Lesser General Public License as published by the Free Software Foundation; either version 
 * 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; 
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See 
 * the GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License along with this library;
 * if not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, 
 * MA  02110-1301  USA
 * 
 * You can find the license also here: http://www.gnu.org/copyleft/lesser.html 
 */
package ca.uwaterloo.gsd.icsm2010.wrappers.swt2swing.widgets;

import javax.swing.JComponent;

import ca.uwaterloo.gsd.icsm2010.patterns.FactoryMethod;
import ca.uwaterloo.gsd.icsm2010.patterns.LayeredAdapter;
import ca.uwaterloo.gsd.icsm2010.wrappers.swt2swing.widgets.internal.IList;
import ca.uwaterloo.gsd.icsm2010.wrappers.swt2swing.widgets.internal.IList.IListFactory;

/**
 * Wraps a JList with a ListModel and potentially a JScrollPane.
 * 
 * @author Thiago Tonelli Bartolomei
 */
public class List extends Scrollable {

	// Wrapper Refinement
	JComponent getAdaptee() {
		return (JComponent) adaptee;
	}
	
	@LayeredAdapter
	IList getList() {
		return (IList) adaptee;
	}
	
	@FactoryMethod
	@LayeredAdapter
	void createAdaptee(int style) {
		this.setAdaptee((JComponent) IListFactory.createIList(style));
	}
	
	// Public API
	public List(Composite composite, int style) {
		super(composite, style);
	}
	
	public void add(String s) {
		getList().addElement(s);
	}
	
	public int getItemCount() {
		return getList().getItemCount();
	}
	
	public boolean isSelected(int index) {
		return getList().isSelectedIndex(index);
	}
	
	public String getItem(int index) {
		return getList().get(index);
	}
	
	public void remove(int index) {
		getList().remove(index);
	}
	
	public void add(String item, int index) {
		getList().add(index, item);
	}
}
