/**
 * Copyright (c) 2010 Generative Software Development Lab, University of Waterloo, Canada. All Rights Reserved
 *
 * This library is free software; you can redistribute it and/or modify it under the terms of the 
 * GNU Lesser General Public License as published by the Free Software Foundation; either version 
 * 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; 
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See 
 * the GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License along with this library;
 * if not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, 
 * MA  02110-1301  USA
 * 
 * You can find the license also here: http://www.gnu.org/copyleft/lesser.html 
 */
package ca.uwaterloo.gsd.icsm2010.wrappers.swt2swing.widgets;

import java.awt.Component;

import javax.swing.JFrame;

import ca.uwaterloo.gsd.icsm2010.patterns.FactoryMethod;
import ca.uwaterloo.gsd.icsm2010.wrappers.swt2swing.SWT;

/**
 * Wraps a JFrame and its content pane.
 * 
 * @author Thiago Tonelli Bartolomei
 */
public class Shell extends Decorations {

	// Wrapper Refinement
	JFrame getAdaptee() {
		return (JFrame) adaptee;
	}
	
	@FactoryMethod
	void createAdaptee(int style) {
		this.setAdaptee(new JFrame());
		this.getAdaptee().setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
	}
	
	// Overriding because adding in to content pane
	void add(Component c) {
		getAdaptee().getContentPane().add(c);
	}
	
	// Overriding because children come from content pane
	Component[] getComponents() {
		return getAdaptee().getContentPane().getComponents();
	}
	
	// Public API
	public Shell(Display display) {
		super();
		this.display = display;
		this.createAdaptee(SWT.SHELL_TRIM);
	}
	
	public void open() {
		getAdaptee().setVisible(true);
	}
}
