/**
 * Copyright (c) 2010 Generative Software Development Lab, University of Waterloo, Canada. All Rights Reserved
 *
 * This library is free software; you can redistribute it and/or modify it under the terms of the 
 * GNU Lesser General Public License as published by the Free Software Foundation; either version 
 * 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; 
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See 
 * the GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License along with this library;
 * if not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, 
 * MA  02110-1301  USA
 * 
 * You can find the license also here: http://www.gnu.org/copyleft/lesser.html 
 */
package ca.uwaterloo.gsd.icsm2010.wrappers.swt2swing.widgets;

import java.awt.Component;
import java.util.Map;
import java.util.WeakHashMap;

import ca.uwaterloo.gsd.icsm2010.patterns.FactoryMethod;
import ca.uwaterloo.gsd.icsm2010.patterns.ObjectAdapter;
import ca.uwaterloo.gsd.icsm2010.patterns.StatefulAdapter;
import ca.uwaterloo.gsd.icsm2010.patterns.WrappingIdentityMap;

/**
 * This sits on top of the widget inheritance hierarchy.
 * 
 * This surrogate implements a lot of infrastructure for all types, such as
 * factory methods, the main object adapter field and wrapping identity map.
 * 
 * @author Thiago Tonelli Bartolomei
 */
public abstract class Widget {

	@ObjectAdapter
	Component adaptee = null;
	
	Component getAdaptee() {
		return adaptee;
	}
	
	void setAdaptee(Component c) {
		this.adaptee = c;
		this.registerAdaptee(c);
	}
	
	@StatefulAdapter
	boolean disposed = false;
	
	@StatefulAdapter
	int style;
	
	// Extra reference to surrogate
	Display display = null;
	
	@WrappingIdentityMap
	Widget() {}
	
	Widget(Composite parent, int style) {
		this.display = parent.display;
		createAdaptee(style);
		parent.add(getAdaptee());
	}
	
	@FactoryMethod
	abstract void createAdaptee(int style);	
	
	@WrappingIdentityMap
	private static Map<Component, Widget> map = new WeakHashMap<Component, Widget>();
	
	@WrappingIdentityMap
	void registerAdaptee(Component adaptee) {
		map.put(adaptee, this);
	}
	
	@WrappingIdentityMap
	Widget getSurrogate(Component adaptee, Class<?> surrogateClass) {
		if (! map.containsKey(adaptee)) {
			map.put(adaptee, createSurrogate(adaptee, surrogateClass));
		}
		return map.get(adaptee);
	}
	
	@WrappingIdentityMap
	Widget createSurrogate(Component adaptee, Class<?> surrogateClass) {
		// TODO not needed in this example.
		return null;
	}
	
	// Public API
	public boolean isDisposed() {
		return disposed;
	}
}
